@@ -3,6 +3,7 @@ import logging
 import warnings
 from time import gmtime
 import pkg_resources
+from . import _version
 
 # saved in case needed in the future
 # warnings.filterwarnings('ignore', category=UserWarning, module='rsudp')
@@ -14,11 +15,12 @@ Contains logging and formatting resources for command line and logfile output of
 '''
 
 name = 'rsudp'
-__version__ = pkg_resources.require(name)[0].version
+__version__ = _version.version
 
 default_loc = '%s/.config/rsudp' % os.path.expanduser('~').replace('\\', '/')
 os.makedirs(default_loc, exist_ok=True)
 log_dir = os.path.abspath('/tmp/rsudp')
+log_name = 'rsudp.log'
 os.makedirs(log_dir, exist_ok=True)
 
 # formatter settings
@@ -30,6 +32,7 @@ TIME_FORMAT = '%Y-%m-%d %H:%M:%S'
 output_dir = False
 data_dir = False
 scap_dir = False
+ms_path = False
 
 COLOR = {
 	'purple': '\033[95m',
@@ -98,7 +101,7 @@ def init_dirs(odir):
 	return True
 
 
-def start_logging(testing=False):
+def start_logging(logname=log_name, testing=False):
 	'''
 	Creates a handler for logging info and warnings to file.
 
@@ -117,7 +120,7 @@ def start_logging(testing=False):
 	formatter = logging.Formatter(fmt=LOGFORMAT, datefmt=TIME_FORMAT)
 
 	# this initializes logging to file
-	f = logging.FileHandler(os.path.join(log_dir, 'rsudp.log'))
+	f = logging.FileHandler(os.path.join(log_dir, logname))
 	f.setLevel('INFO')
 	f.setFormatter(formatter)
 	# warnings also go to file
