@@ -3,8 +3,6 @@ import signal
 import getopt
 import time
 import json
-import re
-import logging
 import traceback
 from queue import Queue
 from rsudp import printM, printW, printE, default_loc, init_dirs, output_dir, add_debug_handler, start_logging
@@ -28,17 +26,14 @@ from rsudp.c_rsam import RSAM
 from rsudp.c_testing import Testing
 from rsudp.t_testdata import TestData
 import pkg_resources as pr
-import fnmatch
-try:
-	from pydub import AudioSegment
-	PYDUB_EXISTS = True
-except ImportError:
-	PYDUB_EXISTS = False
 
 
 DESTINATIONS, THREADS = [], []
 PROD = False
 PLOTTER = False
+TELEGRAM = False
+TWITTER = False
+WRITER = False
 SOUND = False
 TESTING = False
 TESTQUEUE = False
@@ -110,13 +105,13 @@ def start():
 	global PROD, PLOTTER, THREADS, DESTINATIONS
 	# master queue and consumer
 	queue = Queue(rs.qsize)
-	cons = Consumer(queue, DESTINATIONS)
+	cons = Consumer(queue, DESTINATIONS, testing=TESTING)
 	cons.start()
 
 	for thread in THREADS:
 		thread.start()
 
-	PROD = Producer(queue, THREADS)
+	PROD = Producer(queue, THREADS, testing=TESTING)
 	PROD.start()
 
 	if PLOTTER and MPL:
@@ -173,15 +168,17 @@ def run(settings, debug):
 	if settings['printdata']['enabled']:
 		# set up queue and process
 		q = mk_q()
-		prnt = PrintRaw(q)
+		prnt = PrintRaw(q, testing=TESTING)
 		mk_p(prnt)
 
 	if settings['write']['enabled']:
+		global WRITER
 		# set up queue and process
 		cha = settings['write']['channels']
 		q = mk_q()
-		writer = Write(q=q, cha=cha)
-		mk_p(writer)
+		WRITER = Write(q=q, data_dir=output_dir,
+					   cha=cha, testing=TESTING)
+		mk_p(WRITER)
 
 	if settings['plot']['enabled'] and MPL:
 		while True:
@@ -207,7 +204,7 @@ def run(settings, debug):
 		pq = mk_q()
 		PLOTTER = Plot(cha=cha, seconds=sec, spectrogram=spec,
 						fullscreen=full, kiosk=kiosk, deconv=deconv, q=pq,
-						screencap=screencap, alert=alert)
+						screencap=screencap, alert=alert, testing=TESTING)
 		# no mk_p() here because the plotter must be controlled by the main thread (this one)
 
 	if settings['forward']['enabled']:
@@ -215,10 +212,21 @@ def run(settings, debug):
 		addr = settings['forward']['address']
 		port = settings['forward']['port']
 		cha = settings['forward']['channels']
+		fwd_data = settings['forward']['fwd_data']
+		fwd_alarms = settings['forward']['fwd_alarms']
 		# set up queue and process
-		q = mk_q()
-		forward = Forward(addr=addr, port=port, cha=cha, q=q)
-		mk_p(forward)
+		if len(addr) == len(port):
+			printM('Initializing %s Forward threads' % (len(addr)), sender=SENDER)
+			for i in range(len(addr)):
+				q = mk_q()
+				forward = Forward(num=i, addr=addr[i], port=int(port[i]), cha=cha,
+								  fwd_data=fwd_data, fwd_alarms=fwd_alarms,
+								  q=q, testing=TESTING)
+				mk_p(forward)
+		else:
+			printE('List length mismatch: %s addresses and %s ports in forward section of settings file' % (
+										len(addr), len(port)), sender=SENDER)
+			_xit(1)
 
 	if settings['alert']['enabled']:
 		# put settings in namespace
@@ -239,40 +247,17 @@ def run(settings, debug):
 		# set up queue and process
 		q = mk_q()
 		alrt = Alert(sta=sta, lta=lta, thresh=thresh, reset=reset, bp=bp,
-					 cha=cha, debug=debug, q=q,
+					 cha=cha, debug=debug, q=q, testing=TESTING,
 					 deconv=deconv)
 		mk_p(alrt)
 
 	if settings['alertsound']['enabled']:
-		sender = 'AlertSound'
-		SOUND = False
-		soundloc = False
-		if PYDUB_EXISTS:
-			soundloc = os.path.expanduser(os.path.expanduser(settings['alertsound']['mp3file']))
-			if soundloc in ['doorbell', 'alarm', 'beeps', 'sonar']:
-				soundloc = pr.resource_filename('rsudp', os.path.join('rs_sounds', '%s.mp3' % soundloc))
-			if os.path.exists(soundloc):
-				try:
-					SOUND = AudioSegment.from_file(soundloc, format="mp3")
-					printM('Loaded %.2f sec alert sound from %s' % (len(SOUND)/1000., soundloc), sender='AlertSound')
-				except FileNotFoundError as e:
-					printW("You have chosen to play a sound, but don't have ffmpeg or libav installed.", sender='AlertSound')
-					printW('Sound playback requires one of these dependencies.', sender='AlertSound', spaces=True)
-					printW("To install either dependency, follow the instructions at:", sender='AlertSound', spaces=True)
-					printW('https://github.com/jiaaro/pydub#playback', sender='AlertSound', spaces=True)
-					printW('The program will now continue without sound playback.', sender='AlertSound', spaces=True)
-					SOUND = False
-			else:
-				printW("The file %s could not be found." % (soundloc), sender='AlertSound')
-				printW('The program will now continue without sound playback.', sender='AlertSound', spaces=True)
-		else:
-			printW("You don't have pydub installed, so no sound will play.", sender='AlertSound')
-			printW('To install pydub, follow the instructions at:', sender='AlertSound', spaces=True)
-			printW('https://github.com/jiaaro/pydub#installation', sender='AlertSound', spaces=True)
-			printW('Sound playback also requires you to install either ffmpeg or libav.', sender='AlertSound', spaces=True)
+		soundloc = os.path.expanduser(os.path.expanduser(settings['alertsound']['mp3file']))
+		if soundloc in ['doorbell', 'alarm', 'beeps', 'sonar']:
+			soundloc = pr.resource_filename('rsudp', os.path.join('rs_sounds', '%s.mp3' % soundloc))
 
 		q = mk_q()
-		alsnd = AlertSound(q=q, sound=SOUND, soundloc=soundloc)
+		alsnd = AlertSound(q=q, testing=TESTING, soundloc=soundloc)
 		mk_p(alsnd)
 
 	runcustom = False
@@ -297,35 +282,37 @@ def run(settings, debug):
 	if runcustom:
 		# set up queue and process
 		q = mk_q()
-		cstm = Custom(q=q, codefile=f, win_ovr=win_ovr)
+		cstm = Custom(q=q, codefile=f, win_ovr=win_ovr, testing=TESTING)
 		mk_p(cstm)
 
 
 	if settings['tweets']['enabled']:
+		global TWITTER
 		consumer_key = settings['tweets']['api_key']
 		consumer_secret = settings['tweets']['api_secret']
 		access_token = settings['tweets']['access_token']
 		access_token_secret = settings['tweets']['access_secret']
 		tweet_images = settings['tweets']['tweet_images']
+		extra_text = settings['tweets']['extra_text']
 
 		q = mk_q()
-		tweet = Tweeter(q=q, consumer_key=consumer_key, consumer_secret=consumer_secret,
+		TWITTER = Tweeter(q=q, consumer_key=consumer_key, consumer_secret=consumer_secret,
 						access_token=access_token, access_token_secret=access_token_secret,
-						tweet_images=tweet_images)
-		mk_p(tweet)
+						tweet_images=tweet_images, extra_text=extra_text, testing=TESTING)
+		mk_p(TWITTER)
 
 	if settings['telegram']['enabled']:
+		global TELEGRAM
 		token = settings['telegram']['token']
 		chat_ids = settings['telegram']['chat_id'].strip(' ').split(',')
 		send_images = settings['telegram']['send_images']
-		
 		for chat_id in chat_ids:
 			sender = "Telegram id %s" % (chat_id)
 			q = mk_q()
-			telegram = Telegrammer(q=q, token=token, chat_id=chat_id,
-								   send_images=send_images,
+			TELEGRAM = Telegrammer(q=q, token=token, chat_id=chat_id,
+								   send_images=send_images, testing=TESTING,
 								   sender=sender)
-			mk_p(telegram)
+			mk_p(TELEGRAM)
 
 	if settings['rsam']['enabled']:
 		# put settings in namespace
@@ -345,8 +332,9 @@ def run(settings, debug):
 
 		# set up queue and process
 		q = mk_q()
-		rsam = RSAM(q=q, debug=debug, interval=interval, cha=cha, deconv=deconv,
-					fwaddr=fwaddr, fwport=fwport, fwformat=fwformat, quiet=quiet)
+		rsam = RSAM(q=q, interval=interval, cha=cha, deconv=deconv,
+					fwaddr=fwaddr, fwport=fwport, fwformat=fwformat,
+					quiet=quiet, testing=TESTING)
 
 		mk_p(rsam)
 
@@ -372,8 +360,6 @@ def run(settings, debug):
 		_xit()
 	else:
 		printW('Client has exited, ending tests...', sender=SENDER, announce=False)
-		if SOUND:
-			T.TEST['d_pydub'][1] = True
 
 
 def main():
@@ -459,11 +445,10 @@ settings in %s
 			'''
 			settings = H.read_settings(a)
 
-	start_logging()
 	debug = settings['settings']['debug']
 	if debug:
 		add_debug_handler()
-		printM('Logging initialized successfully.', sender=SENDER)
+	start_logging()
 
 	printM('Using settings file: %s' % settings_loc)
 
@@ -523,6 +508,7 @@ default settings and the data file at
 	settings_are_default = True
 	plot = True
 	quiet = False
+	packetize(inf=TESTFILE+'.ms', outf=TESTFILE, testing=True)
 
 	try:
 		opts = getopt.getopt(sys.argv[1:], 'hf:s:bq',
@@ -549,8 +535,8 @@ default settings and the data file at
 					packetize(inf=a, outf=out)
 					TESTFILE = out
 				except Exception as e:
-					print(COLOR['red'] + 'ERROR: %s' % e + COLOR['white'])
 					print(hlp_txt)
+					print(COLOR['red'] + 'ERROR: %s' % e + COLOR['white'])
 					exit(1)
 		if o in ('-s', '--settings='):
 			'''
@@ -586,11 +572,33 @@ default settings and the data file at
 
 	try:
 		run(settings, debug=True)
+
+		# client test
+		ctest = 'client test'
+		if T.TEST['c_miniseed']:
+			printM('Merging and testing MiniSEED file(s)...', sender=ctest)
+			try:
+				ms = rs.Stream()
+				for outfile in WRITER.outfiles:
+					if os.path.exists(outfile):
+						T.TEST['c_miniseed'][1] = True
+						ms = ms + rs.read(outfile)
+						dn, fn = os.path.dirname(outfile), os.path.basename(outfile)
+						os.replace(outfile, os.path.join(dn, 'test.' + fn))
+					else:
+						raise FileNotFoundError('MiniSEED file not found: %s' % outfile)
+				printM('Renamed test file(s).', sender=ctest)
+				printM(ms.merge())
+			except Exception as e:
+				printE(e)
+				T.TEST['c_miniseed'][1] = False
+
 	except Exception as e:
 		printE(traceback.format_exc(), announce=False)
-		printE('Ending tests.', sender='test client', announce=False)
+		printE('Ending tests.', sender=SENDER, announce=False)
 		time.sleep(0.5)
 
+
 	TESTQUEUE.put(b'ENDTEST')
 	printW('Test finished.', sender=SENDER, announce=False)
 
