@@ -1,5 +1,6 @@
 import rsudp.raspberryshake as rs
 from rsudp import COLOR, printM, printW
+import rsudp
 import os
 import json
 
@@ -49,9 +50,11 @@ def default_settings(output_dir='%s/rsudp' % os.path.expanduser('~').replace('\\
     "units": "CHAN"},
 "forward": {
     "enabled": false,
-    "address": "192.168.1.254",
-    "port": 8888,
-    "channels": ["all"]},
+    "address": ["192.168.1.254"],
+    "port": [8888],
+    "channels": ["all"],
+	"fwd_data": true,
+	"fwd_alarms": false},
 "alert": {
     "enabled": true,
     "channel": "HZ",
@@ -76,7 +79,8 @@ def default_settings(output_dir='%s/rsudp' % os.path.expanduser('~').replace('\\
     "api_key": "n/a",
     "api_secret": "n/a",
     "access_token": "n/a",
-    "access_secret": "n/a"},
+    "access_secret": "n/a",
+	"extra_text": ""},
 "telegram": {
     "enabled": false,
     "send_images": true,
@@ -85,8 +89,8 @@ def default_settings(output_dir='%s/rsudp' % os.path.expanduser('~').replace('\\
 "rsam": {
     "enabled": false,
     "quiet": true,
-    "fwaddr": false,
-    "fwport": false,
+    "fwaddr": "192.168.1.254",
+    "fwport": 8887,
     "fwformat": "LITE",
     "channel": "HZ",
     "interval": 10,
@@ -372,6 +376,21 @@ def get_msg_path(msg):
 	return msg.decode('utf-8').split(' ')[2]
 
 
+def get_scap_dir():
+	'''
+	This function returns the screen capture directory from the init function.
+	This allows the variable to be more threadsafe.
+
+	.. code-block:: python
+
+		>>> get_scap_dir()
+		'/home/pi/rsudp/screenshots/'
+
+	:return: the path of the screenshot directory
+	'''
+	return rsudp.scap_dir
+
+
 def deconv_vel_inst(self, trace, output):
 	'''
 	.. role:: pycode(code)
