@@ -1,14 +1,18 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
 import os, sys
 import getopt
 from obspy import read
 from datetime import timedelta
+from rsudp.test import TEST
+
 
 SMP = {
 	0.01: 25,
 	0.02: 50,
 }
 
-def packetize(inf, outf):
+def packetize(inf, outf, testing=False):
 	'''
 	Reads a seismic data file and converts it to ascii text.
 
@@ -17,7 +21,10 @@ def packetize(inf, outf):
 	'''
 	if os.path.isfile(os.path.expanduser(inf)):
 		stream = read(inf)
-		samps = SMP[stream[0].stats.delta]
+		try:
+			samps = SMP[stream[0].stats.delta]
+		except KeyError as e:
+			raise KeyError('Sampling frequency of %s is not supported. Is this Raspberry Shake data?' % (e))
 		n = 0
 		time = stream[0].stats.starttime
 
@@ -36,8 +43,10 @@ def packetize(inf, outf):
 			f.write('TERM%s' % (os.linesep))
 
 		print('Data written to %s' % outf)
+		if testing:
+			TEST['x_packetize'][1] = True
 	else:
-		print('Input file does not exist.')
+		print('Input file does not exist: %s' % inf)
 
 
 def main():
